
arch=`uname -m`;
platform=`uname -s`;

show_messages () {
	if tty -s; then
		echo $1
	fi
	echo "script `date`:- $1" >>$PSATHOME/console.psat.log;
}

if id | grep "^uid=0(" >/dev/null 2>&1
	then # user IS superuser
       		show_messages "Commencing MCSPubsat service as root."
	else
       		show_messages "MCSPubsat needs to be run as root.";
       	exit 1;
fi


USAGE="Usage: psat.sh { start | stop | status } "

stop_process () {
        cd $PSATHOME;

	if [ "$platform" = 'Linux' ]; then
		pslist=`/bin/ps -elf | grep MCSPubsat`
	else
		pslist=`/bin/ps -ef | grep MCSPubsat`
	fi
			
        show_messages "Attempting to stop MCSPubsat service."
	if [ "$platform" = 'Linux' ]; then
        	PID=`echo "$pslist" | grep -v grep | awk '{ print $4 }'`
        else
        	PID=`echo "$pslist" | grep -v grep | awk '{ print $2 }'`
        fi

        if [ ! -z "$PID" ]; then
        	show_messages "Attempting to stop MCSPubsat PID: $PID.";
            	/bin/kill ${PID} > /dev/null 2>&1;
        fi
}

status_process () {
	if [ "$platform" = 'Linux' ]; then
		pslist=`/bin/ps -elf | grep MCSPubsat`
	else
		pslist=`/bin/ps -ef | grep MCSPubsat`
	fi

	show_messages "Checking for running MCSPubsat service."

	if [ "$platform" = 'Linux' ]; then
		PID=`echo "$pslist" | grep -v grep | awk '{ print $4 }'`;
	else
		PID=`echo "$pslist" | grep -v grep | awk '{ print $2 }'`;
	fi

	if [ ! -z "$PID" ]; then
		show_messages "MCSPubsat process running with PID: $PID.";
	else
		show_messages "Unable to detect the MCSPubsat process running.";
		show_messages "Confirm that you have attempted to start it,";
	fi
}

start_process () {
	# Make sure the path is mounted
	if [ ! -f $PSATHOME/MCSPubsat ]; then
        	show_messages "Unable to find the MCSPubsat executable in directory $PSATHOME.";
		show_messages "Please check that PSATHOME is set correctly in this script.";
        	exit;	
	fi

	# If there is a psat.tar present someone has untared an upgrade but not done a psat_configure.sh
	if [ -f $PSATHOME/psat.tar ]; then
        	show_messages "A psat.tar is present, running configure.";
		sh psat_configure.sh;
        	exit;
	fi

	cd $PSATHOME;

	if [ -s $PSATHOME/MCSPubsat ]; then
		show_messages "MCSPubsat service starting.";
          	MCSPubsat &>>$PSATHOME/console.psat.log &
	else
		show_messages "Unable to find or execute MCSPubsat ($1) service.";
	fi
}

# Check arguments started with
if [ "$1" = 'help' ]; then
        show_messages $USAGE;
        exit 1;
fi

cd $PSATHOME;

# Check arguments started with
if [ ! "$1" = 'stop' ] && [ ! "$1" = 'start' ] && [ ! "$1" = 'status' ]; then
	show_messages "Assuming start";
	start_process;
	show_messages "  ";
	show_messages "To stop MCSPubsat, type 'sh $PSATHOME/psat.sh stop'.";
	show_messages "  ";
    exit 1;
fi

case "$1" in
'start')
	start_process
	;;
'status')
        status_process
        ;;
'stop')
        stop_process
        ;;
*)
        show_messages $USAGE
        ;;
esac
exit 0;
