#!/bin/sh
: Make sure we get executed by sh on all systems

platform=`uname -s`;
arch=`uname -m`;
cdir=`pwd`;
fdir=`pwd`;
initservice=`ps -p1 | grep systemd | awk '{print $4}'`;

if id | grep "^uid=0(" >/dev/null 2>&1
	then # user IS superuser
        	echo "Commencing PublishSatellite configure as root.";
	else
        	echo "PublishSatellite needs to be installed as root.";
        	exit 1;
fi

if [ -f prevlocation ]; then
        mdir=`tail -n 1 prevlocation`;
else
	mdir=$cdir;
fi

echo "=========================================="
echo "What directory would you like to install PublishSatellite?";
if [ -f prevlocation ]; then
       	cdir=`tail -n 1 prevlocation`;
fi
echo " to assume $cdir, just hit <enter>";
read mdir;
if [ -z "$mdir" ]; then
	if [ -f prevlocation ]; then
       		mdir=`tail -n 1 prevlocation`;
		rm prevlocation;
	else
		mdir=$cdir;
	fi
fi

echo "$mdir" > prevlocation;

if [ -f $mdir/psat.sh ]; then
	echo "Previous install detected, please confirm overwrite (y/n)";
	read mconfirm;
	if [ "$mconfirm" != "y" ]; then
		exit 1;
	fi
	sh $mdir/psat.sh stop;
fi

if [ ! -d $mdir ]; then
	mkdir -m 775 -p $mdir;
fi

bnam=`basename $mdir`;
cd $mdir;

if [ "$platform" = 'Linux' ]; then 
	tar -xf $fdir/psat.tar psat_uninstall.sh pubsat.ini PartTwo.sh read_me.txt;
	if [ "$arch" = "x86_64" ]; then
		tar -xf $fdir/psat.tar x86_64PublishSatellite;
         	cp -f x86_64PublishSatellite MCSPubsat;
		chmod +x MCSPubsat;
         	echo "Copying x86 64bit executable live";
         else
         	echo "Please contact support for a 32 bit Publish executable";
         fi
fi

	if [ -f $mdir/start_psat.sh ]; then 
		rm $mdir/start_psat.sh;
	fi
	echo "#!/bin/bash" > $mdir/start_psat.sh;
	echo " " >> $mdir/start_psat.sh;
	echo ": Make sure we get executed by sh on all systems" >> $mdir/start_psat.sh;
	echo "sh $mdir/psat.sh start" >> $mdir/start_psat.sh;
	chmod +x $mdir/start_psat.sh;

	echo "#!/bin/bash" > $mdir/stop_psat.sh;
	echo " " >> $mdir/stop_psat.sh;
	echo ": Make sure we get executed by sh on all systems" >> $mdir/stop_psat.sh;
	echo "sh $mdir/psat.sh stop" >> $mdir/stop_psat.sh;
	chmod +x $mdir/stop_psat.sh;

	if [ "$initservice" = 'systemd' ]; then 
		echo "[Unit]" > $mdir/visualware_psat.service;
		echo "Description=Visualware Publish daemon" >> $mdir/visualware_psat.service;
		echo "After=network.target" >> $mdir/visualware_psat.service;
		echo " " >> $mdir/visualware_psat.service;
		echo "[Service]" >> $mdir/visualware_psat.service;
		echo "Type=forking" >> $mdir/visualware_psat.service;
		echo "WorkingDirectory=$mdir" >>$mdir/visualware_psat.service;
		echo "Environment=PATH=/bin:/usr/bin" >>$mdir/visualware_psat.service;
		echo "ExecStart=/bin/bash $mdir/visualware_psat.sh start" >> $mdir/visualware_psat.service;
		echo "ExecStop=/bin/bash $mdir/visualware_psat.sh stop" >> $mdir/visualware_psat.service;
		echo " " >> $mdir/visualware_psat.service;
		echo "[Install]" >> $mdir/visualware_psat.service;
		echo "WantedBy=multi-user.target" >> $mdir/visualware_psat.service;
	fi
		
	echo "#!/bin/bash" > $mdir/visualware_psat.sh;
	echo "# " >> $mdir/visualware_psat.sh;
	echo "### BEGIN INIT INFO" >> $mdir/visualware_psat.sh;
	echo "# Provides:          visualware_psat" >> $mdir/visualware_psat.sh;
	echo "# Required-Start:    \$all" >> $mdir/visualware_psat.sh;
	echo "# Required-Stop:     \$local_fs" >> $mdir/visualware_psat.sh;
	echo "# Default-Start:     2 3 4 5" >> $mdir/visualware_psat.sh;
	echo "# Default-Stop:      0 1 6" >> $mdir/visualware_psat.sh;
	echo "# Short-Description: psat" >> $mdir/visualware_psat.sh;
	echo "# Description:       Visualware Publish daemon" >> $mdir/visualware_psat.sh;
	echo "### END INIT INFO" >> $mdir/visualware_psat.sh;
	echo "# visualware-psat	This shell script starts and stops Visualware publish script" >> $mdir/visualware_psat.sh;
	echo "# chkconfig: 2345 85 10" >> $mdir/visualware_psat.sh;
	echo "# description: PublishSatellite can perform connection tests" >> $mdir/visualware_psat.sh;
 	echo " " >> $mdir/visualware_psat.sh;
	echo ": Make sure we get executed by sh on all systems" >> $mdir/visualware_psat.sh;
	echo " " >> $mdir/visualware_psat.sh;
	echo "case \"\$1\" in" >> $mdir/visualware_psat.sh;
	echo "'start')" >> $mdir/visualware_psat.sh;
	echo "		sh $mdir/start_psat.sh" >> $mdir/visualware_psat.sh;
        echo "		;;" >> $mdir/visualware_psat.sh;
	echo "'status')" >> $mdir/visualware_psat.sh;
        echo "		sh $mdir/psat.sh status" >> $mdir/visualware_psat.sh;
        echo "		;;" >> $mdir/visualware_psat.sh;
	echo "'stop')" >> $mdir/visualware_psat.sh;
        echo "		sh $mdir/stop_psat.sh" >> $mdir/visualware_psat.sh;
        echo "		;;" >> $mdir/visualware_psat.sh;
	echo "esac" >> $mdir/visualware_psat.sh;
	chmod +x $mdir/visualware_psat.sh;

	echo "#!/bin/bash" > $mdir/psat.sh;
	echo "# " >> $mdir/psat.sh;
	echo ": Make sure we get executed by sh on all systems" >> $mdir/psat.sh;
	echo " " >> $mdir/psat.sh;
	echo "PSATHOME=$mdir" >> $mdir/psat.sh;
	echo "PATH=${dirnam}:/usr/bin:/bin:$mdir:." >> $mdir/psat.sh;
	echo "export PSATHOME PATH" >> $mdir/psat.sh;
	cat PartTwo.sh >> $mdir/psat.sh;
	rm PartTwo.sh $fdir/psat.tar;
	chmod +x $mdir/psat.sh;

echo "Checking if service exists";
if [ -f /etc/init.d/visualware_psat ]; then
	rm /etc/init.d/visualware_psat;
	/usr/sbin/update-rc.d -f visualware_psat remove;
fi
if [ -f /etc/systemd/system/visualware_psat.service ]; then
	systemctl stop visualware_psat;
	systemctl disable visualware_psat;
	rm $dest/visualware_psat.service;
fi
if [ -f /etc/init.d/$bnam ]; then
	rm /etc/init.d/$bnam;
	/usr/sbin/update-rc.d -f $bnam remove;
fi
if [ -f /etc/rc.d/init.d/$bnam ]; then
	chkconfig --del $bnam;
fi
if [ -f /etc/rc.d/init.d/visualware_psat ]; then
	chkconfig --del visualware_psat;
fi

if [ "$initservice" = 'systemd' ]; then 
        echo "=========================================="
        echo "Do you want PublishSatellite to automatically run everytime the machine starts y or n?";
        read cservice;
	dest="/etc/systemd/system";
        if [ "$cservice" = "y" ]; then
                cp $mdir/visualware_psat.service $dest/visualware_psat.service;
		systemctl enable visualware_psat;
		systemctl start visualware_psat;
		echo "Starting Visualware Publish service";
        fi
elif [ -x /usr/sbin/update-rc.d ]; then
        echo "=========================================="
        echo "Do you want PublishSatellite to automatically run everytime the machine starts y or n?";
        read cservice;
        dest="/etc/init.d";
        if [ "$cservice" = "y" ]; then
                cp $mdir/visualware_psat.sh $dest/visualware_psat;
                /usr/sbin/update-rc.d visualware_psat start 90 2 3 4 5 . stop 90 0 1 6 .;
        fi
elif [ -x /sbin/chkconfig ]; then
	echo "=========================================="
	echo "Do you want PublishSatellite to automatically run everytime the machine starts y or n?";
	read cservice;
	if [ -f /etc/debian_version ]; then
		dest="/etc/init.d";
	elif [ -f /etc/SuSE-release ]; then
		dest="/etc/init.d";
	else
		dest="/etc/rc.d/init.d";
	fi
	if [ "$cservice" = "y" ]; then
		cp $mdir/visualware_psat.sh $dest/visualware_psat;
		chkconfig --add visualware_psat;
	fi
fi
echo "=========================================="
echo "Installation complete";
echo "=========================================="

if [ "$initservice" != 'systemd' ]; then 
	echo "Starting Visualware Publish service";
	sh $mdir/start_psat.sh;
fi
